@@ -1,14 +1,30 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
-# garbage collection
-import gc
-gc.enable()
+# Nagstamon - Nagios status monitor for your desktop
+# Copyright (C) 2008-2013 Henri Wahl <h.wahl@ifw-dresden.de> et al.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+
 
 import sys
 import os
 import os.path
 import Queue
+import platform
+import socket
 
 try:
     import pygtk
@@ -41,18 +57,41 @@ try:
     Resources = pkg_resources.resource_filename("Nagstamon", "resources")
 except Exception, err:
     # get resources directory from current directory - only if not being set before by pkg_resources
-    if Resources == "":
-        if os.path.exists(os.path.normcase(os.getcwd() + os.sep + "Nagstamon" + os.sep + "resources")):
-            Resources = os.path.normcase(os.getcwd() + os.sep + "Nagstamon" + os.sep + "resources")
-        else:
-            Resources = os.path.normcase(os.getcwd() + os.sep + "resources")
+    # try-excepts necessary for platforms like Windows .EXE
+    join = os.path.join
+    normcase = os.path.normcase
+    paths_to_check = [normcase(join(os.getcwd(), "Nagstamon", "resources")),
+            normcase(join(os.getcwd(), "resources"))]
+    try:
+        # if resources dir is not available in CWD, try the
+        # libs dir (site-packages) for the current Python
+        from distutils.sysconfig import get_python_lib
+        paths_to_check.append(normcase(join(get_python_lib(), "Nagstamon", "resources")))
+    except:
+        pass
+
+    #if we're still out of luck, maybe this was a user scheme install
+    try:
+        import site
+        site.getusersitepackages() #make sure USER_SITE is set
+        paths_to_check.append(normcase(join(site.USER_SITE, "Nagstamon", "resources")))
+    except:
+        pass
+
+    # add directory nagstamon.py where nagstamon.py resides for cases like 0install without installed pkg-resources
+    paths_to_check.append(os.sep.join(sys.argv[0].split(os.sep)[:-1] + ["Nagstamon", "resources"]))
+
+    for path in paths_to_check:
+        if os.path.exists(path):
+            Resources = path
+            break
 
 # initialize GUI and actions
 # if modules are not available from central python install try the ones in the same directory
 from Nagstamon import GUI
 from Nagstamon import Actions
 
-    
+
 ###### MAIN ##############
 
 # necessary gobject thread initialization
@@ -67,22 +106,23 @@ debug_queue = Queue.Queue()
 # Open windows etc. seen from GUI - locking each other not to do unwanted stuff if some windows interfere
 GUILock = {}
 
-"""
-# create servers
-for server in conf.servers.values():
-    created_server = Actions.CreateServer(server, conf, debug_queue, Resources)
-    if created_server is not None:
-        servers[server.name] = created_server     
-"""
+# fix/patch for https://bugs.launchpad.net/ubuntu/+source/nagstamon/+bug/732544
+socket.setdefaulttimeout(30)
 
 # create servers
 for server in conf.servers.values():
-    if server.save_password == "False" and server.enabled == "True":
+    if ( server.use_autologin == "False" and server.save_password == "False" and server.enabled == "True" ) or ( server.enabled == "True" and server.use_autologin == "True" and server.autologin_key == "" ):
         # the auth dialog will fill the server's username and password with the given values
-        GUI.AuthenticationDialog(server=server, Resources=Resources, conf=conf, debug_queue=debug_queue)        
+        if platform.system() == "Darwin":
+            # MacOSX gets instable with default theme "Clearlooks" so use custom one with theme "Murrine"
+            gtk.rc_parse_string('gtk-theme-name = "Murrine"')
+
+        GUI.AuthenticationDialog(server=server, Resources=Resources, conf=conf, debug_queue=debug_queue)
     created_server = Actions.CreateServer(server, conf, debug_queue)
     if created_server is not None:
-        servers[server.name] = created_server   
+        servers[server.name] = created_server
+        # for the next time no auth needed
+        servers[server.name].refresh_authentication = False
 
 # Initiate Output
 output = GUI.GUI(conf=conf, servers=servers, Resources=Resources, debug_queue=debug_queue, GUILock=GUILock)
@@ -97,14 +137,19 @@ create a new one for your custom start of Nagstamon." % ((conf.configdir))
     print "\n" + notice + "\n"
     output.Dialog(type=gtk.MESSAGE_WARNING, buttons=gtk.BUTTONS_OK, message=notice)
 
-
 # Start debugging loop
 debugloop = Actions.DebugLoop(conf=conf, debug_queue=debug_queue, output=output)
 debugloop.start()
 
-# start threaded nagios server checking loop
+# start threaded monitor server checking loop
 Actions.StartRefreshLoop(servers=servers, conf=conf, output=output)
 
+# apparently useless desperate attempt to fix the memory leak -
+# beside its uselessness the leak seems to be less leakier now
+# after some code cleaning
+#garbageloop = Actions.LonesomeGarbageCollector()
+#garbageloop.start()
+
 # if unconfigured nagstamon shows the settings dialog to get settings
 if conf.unconfigured == True:
     GUI.Settings(servers=servers, output=output, conf=conf)
